﻿<?php

session_start();

require 'app/app.php';

$userId = isset($_SESSION['userId']) ? $_SESSION['userId'] : null;
$chatId = isset($_GET['chatId']) ? $_GET['chatId'] : null;

if (!$userId || !$chatId || !App::checkAccess($userId, $chatId)) {
	if ($chatId) {
		header("Location: join.php?chatId=$chatId");
	} else {
		header("Location: index.php");
	}
	die;
}

App::updateActivity($userId);

if (isset($_POST['message']) && !empty($_POST['message'])) {
	$message = $_POST['message'];
	App::sendMessage($userId, $message);
	header("Location: chat.php?chatId=$chatId");
	die;
}

$chatInfo = App::getChatInfo($chatId);
$onlineUsersCount = App::getOnlineUsersCount($chatId);
$messages = App::getMessages($chatId);

?>
<!doctype html>
<html>
<head>
	<title>Чат «<?= $chatInfo['name'] ?>»</title>
	<link rel="stylesheet" href="static/bootstrap/css/bootstrap.min.css">
	<style>
	.layout {
		margin-top: 30px;
	}
	</style>
</head>
<body>

<div class="layout">
<div class="container">
  <div class="card">
  <div class="card-header">
    Чат «<?= $chatInfo['name'] ?>»
	<small class="text-muted">
		(<span id="onlineCount"><?= $onlineUsersCount ?></span> онлайн)
	</small>
  </div>
  <div id="messages" class="card-body" style="height: 400px; overflow-y: scroll;">
	<?php foreach($messages['messages'] as $message): ?>
		<p>
			<small class="text-muted">(в <?= $message['datetime'] ?> от <?= $message['username'] ?>)</small>
			<?= $message['message'] ?>
		</p>
	<?php endforeach ?>
  </div>
   <div class="card-body">
	<form id="messageForm" method="POST">
		<div class="form-group">
			<label for="message">Введите сообщение:</label>
			<input type="text" class="form-control" id="message" name="message" placeholder="Введите ваше сообщение в чат">
		</div>
		<button type="submit" class="btn btn-primary">Отправить</button>
	</form>
  </div>
</div>
</div>
</div>



</body>
<script src="static/jquery.min.js"></script>
<script>
$(function() {
	
	var lastId = <?= $messages['lastId'] ?>;
	var messages = $('#messages');
	messages.scrollTop(messages[0].scrollHeight);

	function  refresh (res) {
		lastId = res.lastId;
		$('#onlineCount').text(res.onlineUsersCount);
		var msgCount = res.messages.length;
		var appendHtml = '';
		for (var i = 0; i < msgCount; ++i) {
			appendHtml += '<p><small class="text-muted">(в ' + res.messages[i].datetime + ' от ' + res.messages[i].username + ')</small> ' + res.messages[i].message + '</p>';
		}
		messages.append(appendHtml);
		messages.scrollTop(messages[0].scrollHeight);
	}
  
	setInterval(function(){
	  $.ajax({
		  'method': 'post',
		  'url': 'ajax.php<?= "?chatId=$chatId&lastMsgId=" ?>' + lastId,
		  'dataType': 'json',
		  'success': function(res){
			  refresh(res);
		  }
	  });
	}, 3000);
  
	$('#messageForm').on('submit', function(event) {
		$.ajax({
			'method': 'post',
			'url': 'ajax.php<?= "?chatId=$chatId&lastMsgId=" ?>' + lastId,
			'dataType': 'json',
			'data': {
				'message': $('#message').val()
			},
			'success': function(res){
				refresh(res);
			}
		});
		$('#message').val('');
		event.preventDefault();
	});
});
</script>
</html>