<?php

$config = [
	'host' => 'localhost',
	'dbname' => 'kasyanov_docs',
	'username' => 'root',
	'password' => '',
];

require 'idiorm.php';
ORM::configure('mysql:host=' . $config['host'] . ';dbname=' . $config['dbname'] . '');
ORM::configure('username', $config['username']);
ORM::configure('password', $config['password']);
ORM::configure('driver_options', [PDO::MYSQL_ATTR_INIT_COMMAND => 'SET NAMES utf8']);

class App
{
	
	public static function filterDataArray(array $input)
	{
		$allowedKeys = [
			'name',
			'description',
			'text',
			'parent_id',
			'sort',
			'view_group_id',
			'edit_group_id',
		];
		$result = [];
		foreach ($input as $key => $value) {
			if (in_array($key, $allowedKeys)) {
				$result[$key] = $value;
			}
		}
		return $result;
		//return array_filter($input, function ($key) use ($allowedKeys) {
		//	return in_array($key, $allowedKeys);
		//}, ARRAY_FILTER_USE_KEY);
	}
	
	public static function createDocument(array $data)
	{
		$document = ORM::for_table('documents')->create();
		$data = self::filterDataArray($data);
		foreach ($data as $key => $value) {
			$document->$key = $value;
		}
		$document->save();
		return $document->id();
	}
	
	public static function updateDocument($id, array $data)
	{
		$document = ORM::for_table('documents')->find_one($id);
		$data = self::filterDataArray($data);
		foreach ($data as $key => $value) {
			$document->$key = $value;
		}
		$document->save();
	}
	
	public static function getDocument($id)
	{
		return ORM::for_table('documents')->find_one($id);
	}
	
	
	public static function getList($ignoreId = null)
	{
		$documents = ORM::for_table('documents')->find_many();
		$result = [];
		foreach ($documents as $document) {
			if ($document->id != $ignoreId) {
				$result[$document->id] = $document->name;
			}
		}
		return $result;
	}
	
	public static function getTree()
	{
		$documents = ORM::for_table('documents')->order_by_asc('sort')->find_many();
		$result = [];
		foreach ($documents as $document) {
			$parentId = 0;
			if (!empty($document->parent_id)) {
				$parentId = $document->parent_id;
				if (!isset($result[$parentId])) {
					$result[$parentId] = [];
				}
			}
			$result[$parentId][] = [
				'id' => $document->id,
				'name' => $document->name,
			];
		}
		return $result;
	}
	
}
